<?php namespace EscapeWork\Manager\Http\Controllers;

use EscapeWork\Manager\Repositories\RoleRepository;
use EscapeWork\Manager\Repositories\PageRepository;
use EscapeWork\Manager\Facades\ManagerAuth;
use EscapeWork\Manager\Http\Requests\Role\FormRequest;

class RolesController extends Controller
{

    public function __construct(RoleRepository $role, PageRepository $page)
    {
        parent::__construct();

        $this->role = $role;
        $this->page = $page;

        // $this->validatePermissions('roles');
    }

    public function index()
    {
        return view(config('manager.views.roles.index'), [
            'roles' => $this->role->allowed(ManagerAuth::user()),
        ]);
    }

    public function create()
    {
        return view(config('manager.views.roles.create'), [
            'role'  => $this->role,
            'pages' => $this->page->all(),
        ]);
    }

    public function store(FormRequest $request)
    {
        $role = $this->dispatchFrom('EscapeWork\Manager\Commands\Role\SaveRoleCommand', $request);

        return redirect(route('manager.roles.index'))
                ->with('message', trans('manager::roles.messages.store', [
                    'role' => $request->title
                ])
            );
    }

    public function edit($id)
    {
        $this->role = $this->role->findOrFail($id);
        $this->role->load('pages');

        $view        = view(config('manager.views.roles.edit'));
        $view->role  = $this->role;
        $view->pages = $this->page->all();

        return $view;
    }

    public function update($id, FormRequest $request)
    {
        $this->dispatchFrom('EscapeWork\Manager\Commands\Role\SaveRoleCommand', $request);

        return redirect(route('manager.roles.index'))
                ->with('message', trans('manager::roles.messages.update', [
                    'role' => $request->title
                ])
            );
    }

    /**
     * Destroying the role
     */
    public function destroy($id)
    {
        $this->role = $this->role->findOrFail($id);
        $this->role->delete();

        return redirect(route('manager.roles.index'))
                ->with('message', trans('manager::roles.messages.delete', [
                    'role' => $this->role->title
                ])
            );
    }
}
